==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/es.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "Todos" : "Todos",
    "{actor} created calendar {calendar}" : "{actor} creó el calendario {calendar}",
    "You created calendar {calendar}" : "Usted creó el calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} eliminó el calendario {calendar}",
    "You deleted calendar {calendar}" : "Usted eliminó el calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} actualizó el calendario {calendar}",
    "You updated calendar {calendar}" : "Usted actualizó el calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} compartió el calendario {calendar} con usted",
    "You shared calendar {calendar} with {user}" : "Usted compartió el calendario {calendar} con {usuario}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartió el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} dejó de compartir el calendario {calendar} con usted",
    "You unshared calendar {calendar} from {user}" : "Usted dejó de compartir el calendario {calendar} de {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} dejó de compartir el calendario {calendar} del usuario{user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} dejó de compartir su propio calendario {calendar}",
    "You shared calendar {calendar} with group {group}" : "Usted compartió el calendario {calendar} con el grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartió el calendario {calendar} con el grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Usted dejó de compartir el calendario {calendar} del grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} dejó de compartir el calendario {calendar} del grupo {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creó el evento {event} en el calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Usted creó el evento {event} en el calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} eliminó el evento {event} del calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Usted eliminó el evento {event} del calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} actualizó el evento {event} en el calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Usted actualizó el evento {event} en el calendario {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} creó la tarea {todo} en la lista {calendar}",
    "You created todo {todo} in list {calendar}" : "Usted creó la tarea {todo} en la lista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} eliminó la tarea {todo} de la lista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Usted eliminó la tarea {tod} de la lista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} actualizó la tarea {todo }en la lista {calendar}",
    "You updated todo {todo} in list {calendar}" : "Usted actualizó la tarea {todo} en la lista {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} completó la tarea {todo} en la lista {calendar}",
    "You solved todo {todo} in list {calendar}" : "Usted completó la tarea {todo} en la lista {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} reabrió la tarea {todo} en la lista {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Usted reabrió la tarea {todo} en la lista {calendar}",
    "A <strong>calendar</strong> was modified" : "Un <strong>calendario</strong> fue modificado.",
    "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> del calendario fue modificado.",
    "A calendar <strong>todo</strong> was modified" : "Una <strong>lista de tareas</strong> fue modificada",
    "Contact birthdays" : "Cumpleaños del contacto",
    "Personal" : "Personal",
    "Contacts" : "Contactos",
    "WebDAV" : "WebDAV",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Dirección remota: %s",
    "Request ID: %s" : "ID de la solicitud: %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/es.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "Todos" : "Todos",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} creó el calendario {calendar}",
    "You created calendar {calendar}" : "Usted creó el calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} eliminó el calendario {calendar}",
    "You deleted calendar {calendar}" : "Usted eliminó el calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} actualizó el calendario {calendar}",
    "You updated calendar {calendar}" : "Usted actualizó el calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} compartió el calendario {calendar} con usted",
    "You shared calendar {calendar} with {user}" : "Usted compartió el calendario {calendar} con {usuario}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} compartió el calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} dejó de compartir el calendario {calendar} con usted",
    "You unshared calendar {calendar} from {user}" : "Usted dejó de compartir el calendario {calendar} de {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} dejó de compartir el calendario {calendar} del usuario{user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} dejó de compartir su propio calendario {calendar}",
    "You shared calendar {calendar} with group {group}" : "Usted compartió el calendario {calendar} con el grupo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} compartió el calendario {calendar} con el grupo {group}",
    "You unshared calendar {calendar} from group {group}" : "Usted dejó de compartir el calendario {calendar} del grupo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} dejó de compartir el calendario {calendar} del grupo {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} creó el evento {event} en el calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Usted creó el evento {event} en el calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} eliminó el evento {event} del calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Usted eliminó el evento {event} del calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} actualizó el evento {event} en el calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Usted actualizó el evento {event} en el calendario {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} creó la tarea {todo} en la lista {calendar}",
    "You created todo {todo} in list {calendar}" : "Usted creó la tarea {todo} en la lista {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} eliminó la tarea {todo} de la lista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Usted eliminó la tarea {tod} de la lista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} actualizó la tarea {todo }en la lista {calendar}",
    "You updated todo {todo} in list {calendar}" : "Usted actualizó la tarea {todo} en la lista {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} completó la tarea {todo} en la lista {calendar}",
    "You solved todo {todo} in list {calendar}" : "Usted completó la tarea {todo} en la lista {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} reabrió la tarea {todo} en la lista {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Usted reabrió la tarea {todo} en la lista {calendar}",
    "A <strong>calendar</strong> was modified" : "Un <strong>calendario</strong> fue modificado.",
    "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> del calendario fue modificado.",
    "A calendar <strong>todo</strong> was modified" : "Una <strong>lista de tareas</strong> fue modificada",
    "Contact birthdays" : "Cumpleaños del contacto",
    "%s via %s" : "%s vía %s",
    "Invitation canceled" : "Invitación cancelada",
    "Hello %s," : "Hola, %s:",
    "The meeting »%s« with %s was canceled." : "La reunión »%s« con %s se ha cancelado.",
    "Invitation updated" : "Invitación actualizada",
    "The meeting »%s« with %s was updated." : "La reunión »%s« con %s se ha actualizado.",
    "%s invited you to »%s«" : "%s te ha invitado a »%s«",
    "When:" : "Cuándo:",
    "Where:" : "Dónde:",
    "Description:" : "Descripción:",
    "Link:" : "Enlace:",
    "Contacts" : "Contactos",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Dirección remota: %s",
    "Request ID: %s" : "ID de la solicitud: %s",
    "CalDAV server" : "Servidor CalDAV",
    "Send invitations to attendees" : "Enviar invitaciones a los asistentes",
    "Please make sure to properly set up the email settings above." : "Por favor, asegúrate de que las configuraciones de correo de arriba son correctas"
},
"nplurals=2; plural=(n != 1);");
